0.9.9 API documentation: color_space.hpp Source File

| 0.9.9 API documentation

- Main Page
- Modules
- Files

- File List

gtx/color_space.hpp
Go to the documentation of this file.
1
13 #pragma once
14
15 // Dependency:
16 #include "../glm.hpp"
17
18 #if GLM_MESSAGES == GLM_ENABLE && !defined(GLM_EXT_INCLUDED)
19 # ifndef GLM_ENABLE_EXPERIMENTAL
20 # pragma message("GLM: GLM_GTX_color_space is an experimental extension and may change in the future. Use #define GLM_ENABLE_EXPERIMENTAL before including it, if you really want to use it.")
21 # else
22 # pragma message("GLM: GLM_GTX_color_space extension included")
23 # endif
24 #endif
25
26 namespace glm
27 {
30
33 template<typename T, qualifier Q>
34 GLM_FUNC_DECL vec<3, T, Q> rgbColor(
35 vec<3, T, Q> const& hsvValue);
36
39 template<typename T, qualifier Q>
40 GLM_FUNC_DECL vec<3, T, Q> hsvColor(
41 vec<3, T, Q> const& rgbValue);
42
45 template<typename T>
46 GLM_FUNC_DECL mat<4, 4, T, defaultp> saturation(
47 T const s);
48
51 template<typename T, qualifier Q>
52 GLM_FUNC_DECL vec<3, T, Q> saturation(
53 T const s,
54 vec<3, T, Q> const& color);
55
58 template<typename T, qualifier Q>
59 GLM_FUNC_DECL vec<4, T, Q> saturation(
60 T const s,
61 vec<4, T, Q> const& color);
62
65 template<typename T, qualifier Q>
66 GLM_FUNC_DECL T luminosity(
67 vec<3, T, Q> const& color);
68
70 }//namespace glm
71
72 #include "color_space.inl"
glm::luminosity
GLM_FUNC_DECL T luminosity(vec< 3, T, Q > const &color)
Compute color luminosity associating ratios (0.33, 0.59, 0.11) to RGB canals.
glm::saturation
GLM_FUNC_DECL vec< 4, T, Q > saturation(T const s, vec< 4, T, Q > const &color)
Modify the saturation of a color.
glm::rgbColor
GLM_FUNC_DECL vec< 3, T, Q > rgbColor(vec< 3, T, Q > const &hsvValue)
Converts a color from HSV color space to its color in RGB color space.
glm::hsvColor
GLM_FUNC_DECL vec< 3, T, Q > hsvColor(vec< 3, T, Q > const &rgbValue)
Converts a color from RGB color space to its color in HSV color space.
glm
Definition: common.hpp:20